//
//  AdTimingBidBannerDelegate.h
//  AdTimingBid SDK
//
//  Copyright 2017 AdTimingBid Inc. All rights reserved.
//
#import <Foundation/Foundation.h>

@class AdTimingBidBanner;

NS_ASSUME_NONNULL_BEGIN

/// The methods declared by the AdTimingBidBannerDelegate protocol allow the adopting delegate to respond to messages from the AdTimingBidBanner class and thus respond to operations such as whether the ad has been loaded, the person has clicked the ad.
@protocol AdTimingBidBannerDelegate<NSObject>

@optional

/// Sent when an ad has been successfully loaded.
- (void)AdTimingBidBannerDidLoad:(AdTimingBidBanner *)banner;

/// Sent after an AdTimingBidBanner fails to load the ad.
- (void)AdTimingBidBannerDidFailToLoad:(AdTimingBidBanner *)banner withError:(NSError *)error;

/// Sent immediately before the impression of an AdTimingBidBanner object will be logged.
- (void)AdTimingBidBannerWillExposure:(AdTimingBidBanner *)banner;

/// Sent after an ad has been clicked by the person.
- (void)AdTimingBidBannerDidClick:(AdTimingBidBanner *)banner;

/// Sent when a banner is about to present a full screen content
- (void)AdTimingBidBannerWillPresentScreen:(AdTimingBidBanner *)banner;

/// Sent after a full screen content has been dismissed.
- (void)AdTimingBidBannerDidDismissScreen:(AdTimingBidBanner *)banner;

 /// Sent when a user would be taken out of the application context.
- (void)AdTimingBidBannerWillLeaveApplication:(AdTimingBidBanner *)banner;

@end

NS_ASSUME_NONNULL_END
